@@ -16,6 +16,11 @@ from pytest_gnupg_fixtures import (
 LOGGER = logging.getLogger(__name__)
 
 
+def test_gnupg_email(gnupg_email: str):
+    """Test that a passphrase can be provided."""
+    assert gnupg_email
+
+
 def test_gnupg_gen_key_conf(gnupg_gen_key_conf: Path):
     """Test that a GnuPG script to generate a keypair can be provided."""
     assert gnupg_gen_key_conf.exists()
@@ -25,10 +30,18 @@ def test_gnupg_gen_key_conf(gnupg_gen_key_conf: Path):
 
 def test_gnupg_keypair(gnupg_keypair: GnuPGKeypair):
     """Test that a GnuPG keypair can be initialized."""
+    assert gnupg_keypair.email
     assert gnupg_keypair.fingerprints
-    assert gnupg_keypair.gen_key_conf.exists()
     assert gnupg_keypair.gnupg_home.exists()
     assert gnupg_keypair.keyid
+    assert gnupg_keypair.passphrase
+    assert gnupg_keypair.script.exists()
+    assert gnupg_keypair.uids
+
+
+def test_gnupg_passphrase(gnupg_passphrase: str):
+    """Test that a passphrase can be provided."""
+    assert gnupg_passphrase
 
 
 def test_gnupg_trust_store(gnupg_trust_store: GnuPGTrustStore):
